# 3yzh

A three-circle calculator, It contains Circle Circles and Cylinders.
It is in Chinese.If you konw how to speak and write or mean these,you can use

Now,you can Download and input python 3y and then it will running

Please comply with local laws and regulations, 
User only has the right to use 
The final interpretation belongs to the author 
For mainland China only. 
You can see or read the log in log.py
This means that you have read and agreed to all the above regulations. 

Welcome Download and use!

* MADE IN CHINA,From a Chinese student
* The Peoject in Chinese
The project is about Circle , Circular ring and Cylinder 
This project is in Chinese version and is for mainland China only

my qq emali address:3046479366@qq.com
When you are using this project,You will agree to the following.
1.Follow your local laws and don't break the law. If you break the law, the author will not take any responsibility 
2.When you use the project,please reasonable use .If you find bugs when you're using the project,you can send a emali to 3046479366@qq.com
3.The final interpretation belongs to the author .
4.Don't steal the source code, if you find someone stealing my source code, you can tell me by email, I will give you some compensation
